@@ -111,12 +111,12 @@ gdm_display_check_loop (GdmDisplay *disp)
 	   * that should give people ample time to stop gdm if needed,
 	   * or just wait for the stupid malicious user to get bored
 	   * and go away */
-	  char *s = g_strdup_printf (_("The display server has been shut down "
-				       "about 6 times in the last 90 seconds, "
-				       "it is likely that something bad is "
-				       "going on.  I will wait for 2 minutes "
-				       "before trying again on display %s."),
-				       disp->name);
+	  char *s = g_strdup_printf (C_(N_("The display server has been shut down "
+					   "about 6 times in the last 90 seconds, "
+					   "it is likely that something bad is "
+					   "going on.  I will wait for 2 minutes "
+					   "before trying again on display %s.")),
+					disp->name);
 	  /* only display a dialog box if this is a local display */
 	  if (disp->type == TYPE_LOCAL ||
 	      disp->type == TYPE_FLEXI) {
@@ -164,16 +164,18 @@ gdm_display_check_loop (GdmDisplay *disp)
 }
 
 static void
-whack_old_slave (GdmDisplay *d)
+whack_old_slave (GdmDisplay *d, gboolean kill_connection)
 {
     time_t t = time (NULL);
     gboolean waitsleep = TRUE;
 
-    /* This should never happen I don't think, but just in case */
-    if (d->socket_conn != NULL) {
-	    GdmConnection *conn = d->socket_conn;
-	    d->socket_conn = NULL;
-	    gdm_connection_set_close_notify (conn, NULL, NULL);
+    if (kill_connection) {
+	    /* This should never happen I don't think, but just in case */
+	    if (d->socket_conn != NULL) {
+		    GdmConnection *conn = d->socket_conn;
+		    d->socket_conn = NULL;
+		    gdm_connection_set_close_notify (conn, NULL, NULL);
+	    }
     }
 
     if (d->master_notify_fd >= 0) {
@@ -267,7 +269,7 @@ gdm_display_manage (GdmDisplay *d)
     /* If we have an old slave process hanging around, kill it */
     /* This shouldn't be a normal code path however, so it doesn't matter
      * that we are hanging */
-    whack_old_slave (d);
+    whack_old_slave (d, FALSE /* kill_connection */);
 
     /* Ensure that /tmp/.ICE-unix and /tmp/.X11-unix exist and have the
      * correct permissions */
@@ -387,7 +389,7 @@ gdm_display_unmanage (GdmDisplay *d)
 
     /* Kill slave, this may in fact hang for a bit at least until the
      * slave dies, which should be ASAP though */
-    whack_old_slave (d);
+    whack_old_slave (d, TRUE /* kill_connection */);
     
     d->dispstat = DISPLAY_DEAD;
     if (d->type != TYPE_LOCAL)
