@@ -29,11 +29,13 @@ gchar *gdm_verify_user    (GdmDisplay *d,
 			   gboolean local);
 void   gdm_verify_cleanup (GdmDisplay *d);
 void   gdm_verify_check   (void);
+void   gdm_verify_select_user (const char *user);
 /* used in pam */
 gboolean gdm_verify_setup_env (GdmDisplay *d);
 gboolean gdm_verify_setup_user (GdmDisplay *d,
 				const gchar *login,
-				const gchar *display);
+				const gchar *display,
+				char **new_login);
 
 #endif /* GDM_VERIFY_H */
 
